Module: Monsoon
- Defined in:
- lib/monsoon.rb,
lib/monsoon/store.rb,
lib/monsoon/backup.rb,
lib/monsoon/client.rb,
lib/monsoon/version.rb,
lib/monsoon/compress.rb
Defined Under Namespace
Classes: Backup, Client, Compress, Store
Constant Summary collapse
- VERSION =
"0.6.1"
Class Attribute Summary collapse
-
.bucket ⇒ Object
Returns the value of attribute bucket.
-
.key ⇒ Object
Returns the value of attribute key.
-
.mongo_uri ⇒ Object
Returns the value of attribute mongo_uri.
-
.secret ⇒ Object
Returns the value of attribute secret.
Class Method Summary collapse
-
.configure {|_self| ... } ⇒ Object
config/initializers/monsoon.rb (for instance).
-
.perform ⇒ Object
Run the Monsoon process to backup, save, and clean the work.
Class Attribute Details
.bucket ⇒ Object
Returns the value of attribute bucket.
4 5 6 |
# File 'lib/monsoon.rb', line 4 def bucket @bucket end |
.key ⇒ Object
Returns the value of attribute key.
4 5 6 |
# File 'lib/monsoon.rb', line 4 def key @key end |
.mongo_uri ⇒ Object
Returns the value of attribute mongo_uri.
4 5 6 |
# File 'lib/monsoon.rb', line 4 def mongo_uri @mongo_uri end |
.secret ⇒ Object
Returns the value of attribute secret.
4 5 6 |
# File 'lib/monsoon.rb', line 4 def secret @secret end |
Class Method Details
.configure {|_self| ... } ⇒ Object
config/initializers/monsoon.rb (for instance)
Monsoon.configure do |config| config.bucket = 'backups' config.key = 'consumer_key' config.secret = 'consumer_secret' config.mongo_uri = 'mongodb://testuser:[email protected]:10036/app_development' end
15 16 17 18 |
# File 'lib/monsoon.rb', line 15 def configure yield self true end |
.perform ⇒ Object
Run the Monsoon process to backup, save, and clean the work.
Examples
Monsoon.perform
# => True
Returns True
28 29 30 |
# File 'lib/monsoon.rb', line 28 def perform Monsoon::Client.new.run end |